@@ -7,17 +7,18 @@
 #  \____\___/|_| |_| |_|\___|\__(_)_| |_| |_|_|
 #
 #  Sign up for free at http://www.comet.ml
-#  Copyright (C) 2021 Comet ML INC
+#  Copyright (C) 2021-2025 Comet ML INC
 #  This file can not be copied and/or distributed without the express
 #  permission of Comet ML Inc.
 # *******************************************************
 
-__author__ = """Comet ML Inc."""
-__email__ = "mail@comet.ml"
-__version__ = "1.0.2"
-__all__ = ["CometMPM"]
+__all__ = ["CometMPM", "API", "ui"]
+
+from comet_ml import ui
 
 from ._logging import _setup_comet_mpm_logging
+from ._version import __version__  # noqa: F401
+from .api import API
 from .comet_mpm import CometMPM
 
 _setup_comet_mpm_logging()
