@@ -16,11 +16,13 @@ import asyncio as asyncio_module
 import atexit
 import logging
 import os
+import traceback
 from typing import Any, Awaitable, Dict, Iterable, List, Optional, Union
 
 from . import constants, logging_messages, optional_update
+from ._logging import ErrorStore
 from .connection import MPM_BASE_PATH, stream_dataset_file
-from .connection_helpers import sanitize_url, url_join
+from .connection_helpers import url_join
 from .environment import check_environment
 from .events import events_from_dataframe
 from .events.label_event import LabelsEvent
@@ -52,6 +54,7 @@ class CometMPM:
         asyncio: bool = False,
         max_batch_size: Optional[int] = None,
         max_batch_time: Optional[int] = None,
+        raise_on_error_during_init: bool = False,
     ):
         """
         Creates the Comet MPM Event logger object.
@@ -64,6 +67,7 @@ class CometMPM:
             asyncio: Set to True if you are using an Asyncio-based framework like FastAPI.
             max_batch_size: Maximum number of MPM events sent in a batch, can also be configured using the environment variable MPM_MAX_BATCH_SIZE.
             max_batch_time: Maximum time before a batch of events is submitted to MPM, can also be configured using the environment variable MPM_MAX_BATCH_SIZE.
+            raise_on_error_during_init: If set to True, CometMPM will raise exceptions instead of just logging errors during initialization. Default is False for backwards compatibility.
         """
 
         settings_user_values: Dict[str, Union[str, int]] = {}
@@ -88,14 +92,21 @@ class CometMPM:
         else:
             self.disabled = bool(os.getenv("COMET_MPM_DISABLED"))
         self._asyncio = asyncio
+        # Use the provided raise_on_error_during_init value, or fall back to settings value
+        self._raise_on_error_during_init = (
+            raise_on_error_during_init or self._settings.mpm_raise_on_error_during_init
+        )
 
-        comet_url = sanitize_url(extract_comet_url(self._settings))
+        comet_url = extract_comet_url(self._settings)
 
         self._mpm_server_address = ServerAddress(
             base_url=url_join(comet_url, MPM_BASE_PATH),
             api_version="v2",
         )
 
+        # Create instance-specific error store for capturing background thread errors
+        self._error_store = ErrorStore()
+
         if self.disabled:
             self._sender = None
         else:
@@ -106,6 +117,7 @@ class CometMPM:
                 max_batch_time=self._settings.mpm_max_batch_time,
                 asyncio=self._asyncio,
                 batch_sending_timeout=self._settings.mpm_batch_sending_timeout,
+                error_store=self._error_store,
             )
 
             if not self._asyncio:
@@ -244,7 +256,7 @@ class CometMPM:
         stream_dataset_file(
             api_key=self._settings.api_key,
             file_path=file_path,
-            base_url=self._settings.url,
+            base_url=self._mpm_server_address.base_url,
             workspace_name=self._settings.mpm_workspace_name,
             model_name=self._settings.mpm_model_name,
             model_version=self._settings.mpm_model_version,
@@ -387,6 +399,53 @@ class CometMPM:
         else:
             return asyncio_module.sleep(0)
 
+    def get_logging_errors(self, clear: bool = True) -> List[Dict[str, Any]]:
+        """Get any logging errors that occurred during background processing.
+
+        This method allows users to programmatically check for and handle
+        errors that occurred in background threads, such as network failures
+        when sending batch data to the backend.
+
+        Args:
+            clear: If True, clear the error store after retrieving errors.
+                   Defaults to True to prevent memory leaks.
+
+        Returns:
+            List of error dictionaries, each containing:
+            - 'message': The error message
+            - 'logger_name': Name of the logger that produced the error
+            - 'timestamp': ISO timestamp when the error occurred
+            - 'data_affected': Description of what data was affected (optional)
+            - 'traceback': Exception traceback information (optional)
+
+        Example:
+            >>> mpm = CometMPM(...)
+            >>> mpm.log_event(...)
+            >>> mpm.end()
+            >>> errors = mpm.get_logging_errors()
+            >>> if errors:
+            ...     print(f"Found {len(errors)} errors:")
+            ...     for error in errors:
+            ...         print(f"  {error['timestamp']}: {error['message']}")
+        """
+        return self._error_store.get_errors(clear=clear)
+
+    def has_logging_error(self) -> bool:
+        """Check if there are any stored logging errors without retrieving them.
+
+        Returns:
+            True if there are errors in the store, False otherwise.
+
+        Example:
+            >>> mpm = CometMPM(...)
+            >>> mpm.log_event(...)
+            >>> mpm.end()
+            >>> if mpm.has_logging_error():
+            ...     errors = mpm.get_logging_errors()
+            ...     # Handle errors
+        """
+        return self._error_store.has_errors()
+
     def _on_end(self) -> None:
         if not self.disabled:
             assert self._sender is not None
@@ -415,9 +474,22 @@ class CometMPM:
             assert self._sender is not None
             self._sender.connect()
         except (CometMPMBackendException, CometMPMBackendIsNotAvailable) as exc:
-            LOGGER.error(str(exc))
+            error_message = f"Connection failed during initialization: {str(exc)}"
+            LOGGER.error(error_message)
             self.disabled = True
 
+            # Store connection error for programmatic access
+            if hasattr(self, "_error_store") and self._error_store is not None:
+                self._error_store.add_error(
+                    message=error_message,
+                    logger_name="comet_mpm.comet_mpm",
+                    data_affected=None,
+                    traceback_info=traceback.format_exc(),
+                )
+
+            if self._raise_on_error_during_init:
+                raise
+
     async def _do_async_connect(self) -> None:
         try:
             assert self._sender is not None
@@ -426,6 +498,35 @@ class CometMPM:
             LOGGER.error(str(exc))
             self.disabled = True
 
+            # Store connection error for programmatic access
+            if hasattr(self, "_error_store") and self._error_store is not None:
+                self._error_store.add_error(
+                    message=str(exc),
+                    logger_name="comet_mpm.comet_mpm",
+                    data_affected=None,
+                    traceback_info=traceback.format_exc(),
+                )
+
+            if self._raise_on_error_during_init:
+                raise
+        except Exception:
+            # Convert connection errors to CometMPMBackendIsNotAvailable for consistency
+            backend_exc = CometMPMBackendIsNotAvailable()
+            LOGGER.error(str(backend_exc))
+            self.disabled = True
+
+            # Store connection error for programmatic access
+            if hasattr(self, "_error_store") and self._error_store is not None:
+                self._error_store.add_error(
+                    message=str(backend_exc),
+                    logger_name="comet_mpm.comet_mpm",
+                    data_affected=None,
+                    traceback_info=traceback.format_exc(),
+                )
+
+            if self._raise_on_error_during_init:
+                raise backend_exc
+
 
 def _handle_event_output_features(
     output_value: Any,
