@@ -14,10 +14,12 @@
 
 import asyncio
 import logging
+import traceback
 from typing import Any, Optional, Tuple
 
 import aiohttp
 
+from .._logging import ErrorStore
 from ..batch_utils import Batch, split_batch
 from ..connection import send_asyncio_batch_requests, send_asyncio_is_alive
 from ..exceptions import AsyncioSenderNoConnected
@@ -38,6 +40,7 @@ def get_asyncio_sender(
     max_batch_size: int,
     max_batch_time: int,
     batch_sending_timeout: int,
+    error_store: Optional[ErrorStore] = None,
 ) -> "AsyncioSender":
     sender = AsyncioSender(
         api_key=api_key,
@@ -45,6 +48,7 @@ def get_asyncio_sender(
         max_batch_size=max_batch_size,
         max_batch_time=max_batch_time,
         batch_sending_timeout=batch_sending_timeout,
+        error_store=error_store,
     )
 
     return sender
@@ -59,6 +63,7 @@ class AsyncioBackgroundSender:
         max_batch_size: int,
         max_batch_time: int,
         batch_sending_timeout: int,
+        error_store: Optional[ErrorStore] = None,
     ):
         """A background coroutine that reads from the queue, add the items to the batch and sends
         them whenever the batch is ready to be sent. Can only be created only when an event loop is running.
@@ -70,6 +75,7 @@ class AsyncioBackgroundSender:
         self.max_batch_time = max_batch_time
         self.batch = Batch(max_batch_size, self.max_batch_time)
         self.batch_sending_timeout = batch_sending_timeout
+        self.error_store = error_store
 
         self.stop_processing = False
 
@@ -107,25 +113,41 @@ class AsyncioBackgroundSender:
         return False
 
     async def _send_batch(self, batch_to_send: Any) -> None:
-        async with aiohttp.ClientSession() as session:
-            predictions_batch, labels_batch = split_batch(batch_to_send)
+        try:
+            async with aiohttp.ClientSession() as session:
+                predictions_batch, labels_batch = split_batch(batch_to_send)
 
-            if predictions_batch:
-                await send_asyncio_batch_requests(
-                    session=session,
-                    url_endpoint=self.batch_endpoint,
-                    api_key=self.api_key,
-                    batch_sending_timeout=self.batch_sending_timeout,
-                    batch=predictions_batch,
-                )
+                if predictions_batch:
+                    await send_asyncio_batch_requests(
+                        session=session,
+                        url_endpoint=self.batch_endpoint,
+                        api_key=self.api_key,
+                        batch_sending_timeout=self.batch_sending_timeout,
+                        batch=predictions_batch,
+                        error_store=self.error_store,
+                    )
 
-            if labels_batch:
-                await send_asyncio_batch_requests(
-                    session=session,
-                    url_endpoint=self.labels_endpoint,
-                    api_key=self.api_key,
-                    batch_sending_timeout=self.batch_sending_timeout,
-                    batch=labels_batch,
+                if labels_batch:
+                    await send_asyncio_batch_requests(
+                        session=session,
+                        url_endpoint=self.labels_endpoint,
+                        api_key=self.api_key,
+                        batch_sending_timeout=self.batch_sending_timeout,
+                        batch=labels_batch,
+                        error_store=self.error_store,
+                    )
+        except Exception as e:
+            # Log to console for immediate user visibility
+            error_message = f"{BATCH_SENDING_EXCEPTION}. Error: {str(e)}"
+            LOGGER.error(error_message)
+
+            # Store in error store for programmatic access
+            if self.error_store is not None:
+                self.error_store.add_error(
+                    message=error_message,
+                    logger_name="comet_mpm.sender.asyncio_sender",
+                    data_affected=batch_to_send,
+                    traceback_info=traceback.format_exc(),
                 )
 
     async def _check_batch_sending(self) -> None:
@@ -144,6 +166,7 @@ class AsyncioBackgroundSender:
                         api_key=self.api_key,
                         batch_sending_timeout=self.batch_sending_timeout,
                         batch=predictions_batch,
+                        error_store=self.error_store,
                     )
 
                 if labels_batch:
@@ -153,9 +176,21 @@ class AsyncioBackgroundSender:
                         api_key=self.api_key,
                         batch_sending_timeout=self.batch_sending_timeout,
                         batch=labels_batch,
+                        error_store=self.error_store,
                     )
-        except Exception:
-            LOGGER.error(BATCH_SENDING_EXCEPTION, exc_info=True)
+        except Exception as e:
+            # Log to console for immediate user visibility
+            error_message = f"{BATCH_SENDING_EXCEPTION}. Error: {str(e)}"
+            LOGGER.error(error_message)
+
+            # Store in error store for programmatic access
+            if self.error_store is not None:
+                self.error_store.add_error(
+                    message=error_message,
+                    logger_name="comet_mpm.sender.asyncio_sender",
+                    data_affected=batch_to_send,
+                    traceback_info=traceback.format_exc(),
+                )
 
     def close(self, timeout: int = 10) -> None:
         """Force the AsyncioBackgroundSender to stop processing messages"""
@@ -186,6 +221,7 @@ class AsyncioSender(BaseSender):
         max_batch_size: int,
         max_batch_time: int,
         batch_sending_timeout: int,
+        error_store: Optional[ErrorStore] = None,
     ) -> None:
         self.sender_queue: Optional["asyncio.Queue[Any]"] = None
         # We need to wait for the asyncio event loop to be created
@@ -199,6 +235,7 @@ class AsyncioSender(BaseSender):
         self.max_batch_time = max_batch_time
         self.max_batch_size = max_batch_size
         self.batch_sending_timeout = batch_sending_timeout
+        self.error_store = error_store
 
     async def connect(self) -> None:
         if self.sender_queue is None:
@@ -211,6 +248,7 @@ class AsyncioSender(BaseSender):
                 max_batch_size=self.max_batch_size,
                 max_batch_time=self.max_batch_time,
                 batch_sending_timeout=self.batch_sending_timeout,
+                error_store=self.error_store,
             )
             self.background_sender.queue = self.sender_queue
 
@@ -244,6 +282,14 @@ class AsyncioSender(BaseSender):
                 await queue.put(item)
             else:
                 LOGGER.error(MPM_ALREADY_CLOSED_LOG_DATA_WARNING)
+                # Store warning for programmatic access
+                if self.error_store is not None:
+                    self.error_store.add_error(
+                        message=MPM_ALREADY_CLOSED_LOG_DATA_WARNING,
+                        logger_name="comet_mpm.sender.asyncio_sender",
+                        data_affected=[item.create_event_dict()],
+                        traceback_info=None,
+                    )
 
     def close(self, timeout: int = 10) -> None:
         """Called during atexit but users should call join manually. In last resort, synchronously
